FieldDescriptor<T, V> class

Inheritance

Constructors

FieldDescriptor({required String name, required List annotations, Type? elementType, Function? factoryConstructor, required Getter getter, Setter? setter, bool isNullable = false, AbstractType<dynamic, AbstractType<dynamic, AbstractType>>? type})

Properties

annotations → List
finalinherited
elementType → Type?
final
factoryConstructor → Function?
final
getter → Getter
final
hashCode → int
The hash code for this object.
no setterinherited
isFinal → bool
no setter
isNullable → bool
final
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setter → Setter?
final
type ↔ AbstractType<dynamic, AbstractType<dynamic, AbstractType>>
getter/setter pairinherited
typeDescriptor ↔ TypeDescriptor
getter/setter pairinherited

Methods

findAnnotation<A>() → A?
inherited
get(T object) → V?
hasAnnotation<A>() → bool
inherited
inferType(Type type, bool isNullable) → void
inherited
isField() → bool
override
isMethod() → bool
inherited
isWriteable() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(T object, V value) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited